Module event

Module event 

Structs

Event
EventBuffer
Thread-safe event buffer for deferring event emissions during transactions.
EventHub
Central event hub for managing subscriptions and dispatching events

Enums

AllEvent
DirectAccessEntity
DocumentEditingEvent
DocumentFormattingEvent
DocumentInspectionEvent
DocumentIoEvent
DocumentSearchEvent
EntityEvent
LongOperationEvent
Origin
UndoRedoEvent

Type Aliases

Queue