LongOperationManager

Struct LongOperationManager 

pub struct LongOperationManager { /* private fields */ }

Implementations

Source

impl LongOperationManager

pub fn new() -> Self

pub fn set_event_hub(&mut self, event_hub: &Arc<EventHub>)

Inject the event hub to allow sending long operation related events

pub fn start_operation<Op: LongOperation>(&self, operation: Op) -> String

Start a new long operation and return its ID

pub fn get_operation_status(&self, id: &str) -> Option<OperationStatus>

Get the status of an operation

pub fn get_operation_progress(&self, id: &str) -> Option<OperationProgress>

Get the progress of an operation

pub fn cancel_operation(&self, id: &str) -> bool

Cancel an operation

pub fn is_operation_finished(&self, id: &str) -> Option<bool>

Check if an operation is finished

pub fn cleanup_finished_operations(&self)

Remove finished operations from memory

pub fn list_operations(&self) -> Vec<String>

Get list of all operation IDs

pub fn get_operations_summary( &self, ) -> Vec<(String, OperationStatus, OperationProgress)>

Get summary of all operations

pub fn store_operation_result<T: Serialize>( &self, id: &str, result: T, ) -> Result<()>

Store an operation result

pub fn get_operation_result(&self, id: &str) -> Option<String>

Get an operation result