Skip to main contentModule snapshot
Source - EntityTreeSnapshot
- Recursive snapshot of an entity and all its strong-relationship children.
Used for delete undo/redo: snapshot before delete, restore on undo.
- JunctionSnapshot
- Snapshot of entries from a single junction table.
- TableLevelSnapshot
- Complete snapshot of a single entity table level: the entity rows plus all
forward and backward junction tables that reference them.
- TableSnapshot
- Snapshot of rows from a single entity table, stored as postcard-serialized bytes.