Module undo_redo

Module undo_redo 

Structs

CompositeCommand
A composite command that groups multiple commands as one.
UndoRedoManager
Manager for undo and redo operations.

Traits

AsyncUndoRedoCommand
Trait for commands that can be executed asynchronously with progress tracking and cancellation.
UndoRedoCommand
Trait for commands that can be undone and redone.